#ifndef _TARTPLASTICPARA_H_
#define _TARTPLASTICPARA_H_

#include <Riostream.h>
#include <TDOMParser.h>
#include <TXMLNode.h>
#include <TList.h>

#include "segidlist.h"
#include "TArtMap.h"

class TArtPlasticPara : public TNamed {
public:
  TArtPlasticPara(Int_t i, TString n, Int_t f, Double_t tcl, Double_t tcr, Double_t qpedl, Double_t qpedr, Double_t z) :
    id(i), detname(n), fpl(f), tcal_left(tcl), tcal_right(tcr), qped_left(qpedl), qped_right(qpedr), zoffset(z){ }
  ~TArtPlasticPara() { }

  void SetMap(Int_t tlg, Int_t tlc, Int_t trg, Int_t trc, Int_t qlg, Int_t qlc, Int_t qrg, Int_t qrc) {
    map_tleft.SetMap(fpl,PLAT,tlg,tlc); 
    map_tright.SetMap(fpl,PLAT,trg,trc); 
    map_qleft.SetMap(fpl,PLAQ,qlg,qlc); 
    map_qright.SetMap(fpl,PLAQ,qrg,qrc); 
  }

  Int_t GetID() const { return id; }
  TString * GetDetectorName() { return &detname; }
  Int_t GetFpl() const { return fpl; }
  Double_t GetTCalLeft() const { return tcal_left; } 
  Double_t GetTCalRight() const { return tcal_right; } 
  Double_t GetQPedLeft() const { return qped_left; } 
  Double_t GetQPedRight() const { return qped_right; } 
  Double_t GetZoffset() const { return zoffset; } 

  TArtRIDFMap * GetTLMap() { return &map_tleft;  }
  TArtRIDFMap * GetTRMap() { return &map_tright; }
  TArtRIDFMap * GetQLMap() { return &map_qleft;  }
  TArtRIDFMap * GetQRMap() { return &map_qright; }

  friend ostream & operator << (ostream& out, const TArtPlasticPara& p) {
    out << "ID: " << p.id << endl;
    out << "DetectorName: " << p.detname << endl;
    out << "Focal Plane: " << p.fpl << endl;
    out << "Time Calib Left: " << p.tcal_left << endl;
    out << "Time Calib Right: " << p.tcal_right << endl;
    out << "QDC Pedestal Left: " << p.qped_left << endl;
    out << "QDC Pedestal Right: " << p.qped_right << endl;
    out << "Z-position offset: " << p.zoffset << endl;
    out << "Map of T-Left: "  << p.map_tleft << endl;
    out << "Map of T-Right: " << p.map_tright << endl;
    out << "Map of Q-Left: "  << p.map_qleft << endl;
    out << "Map of Q-Right: " << p.map_qright << endl;
    out << endl;
    return out;
  }

private:
  Int_t     id;
  TString   detname;
  Int_t     fpl;
  Double_t  tcal_left;
  Double_t  tcal_right;
  Double_t  qped_left;
  Double_t  qped_right;
  Double_t  zoffset;
  TArtRIDFMap map_tleft;
  TArtRIDFMap map_tright;
  TArtRIDFMap map_qleft;
  TArtRIDFMap map_qright;

  ClassDef(TArtPlasticPara,1);

};

#endif
