#include "TArtRIPS.h"
#include "TArtRIPSPara.h"
#include "TArtCore.h"
#include "TArtFocalPlane.h"
#include "TArtBigRIPSParameters.h"

#include <TList.h>

void TArtRIPSArray::LoadSetup(TArtBigRIPSParameters *para) 
{

  Clear();
  TList *listOfRIPSPara = (TList *)para->GetListOfRIPSPara();
  TIter next(listOfRIPSPara);
  TArtRIPSPara *p;
  while(p = (TArtRIPSPara*)next()) {
    Add(new TArtRIPS(p));
  }

}

//__________________________________________________________
void TArtRIPSArray::LoadFplMap(TArtFocalPlaneArray *fpls) 
{
  for(int i=0;i<GetEntries();i++)
    ((TArtRIPS*)At(i))->LoadFplMap(fpls);
  loadfplmap = true;
}

//__________________________________________________________
void TArtRIPSArray::ClearData()
{
  for(int i=0;i<GetEntries();i++)
    ((TArtRIPS*)At(i))->ClearData();
}

//__________________________________________________________
void TArtRIPSArray::RecoDelta()
{
  for(int i=0;i<GetEntries();i++)
    ((TArtRIPS*)At(i))->RecoDelta();
}

//__________________________________________________________
TArtRIPS::TArtRIPS(TArtRIPSPara *p) : para (p)
{

  matrix = para->GetMatrix();
  if(matrix){
    mat1.ResizeTo(2,1); 
    mat1(0,0) = (*matrix)(0,0); mat1(1,0) = (*matrix)(0,1);
    //mat1.Print();
    mat2.ResizeTo(2,2); 
    mat2(0,0) = (*matrix)(1,0); mat2(0,1) = (*matrix)(5,0);
    mat2(1,0) = (*matrix)(1,1); mat2(1,1) = (*matrix)(5,1);
    //mat2.Print();
    invert_mat2.ResizeTo(2,2);
    invert_mat2 = mat2.Invert();
  }

}

//__________________________________________________________
TArtRIPS::~TArtRIPS() 
{
}

//__________________________________________________________
void TArtRIPS::LoadFplMap(TArtFocalPlaneArray *fpls) 
{
  forward_fpl = NULL;
  backward_fpl = NULL;

  int ffpl = para->GetForwardFpl();
  int bfpl = para->GetBackwardFpl();
  for(int i=0;i<fpls->GetEntries();i++){
    TArtFocalPlane * fpl = (TArtFocalPlane *)fpls->At(i);

    if( fpl->GetFpl() == ffpl ){
      if( NULL == forward_fpl )
	forward_fpl = fpl;
      else
	TArtCore::Info(__FILE__,"multiple fpl is defined!: %d",ffpl);
    }

    if( fpl->GetFpl() == bfpl ){
      if( NULL == backward_fpl )
	backward_fpl = fpl;
      else
	TArtCore::Info(__FILE__,"multiple fpl is defined!: %d",ffpl);
    }
      
  }

  if( forward_fpl && backward_fpl )
    TArtCore::Info(__FILE__,"define rips for fpl%d - fpl%d",ffpl,bfpl);
  else
    TArtCore::Info(__FILE__,"could not define rips for fpl%d - fpl%d !!",ffpl,bfpl);

}

//__________________________________________________________
void TArtRIPS::ClearData()
{
  angle = -9999.;
  delta = -9999;
  return;
}

//__________________________________________________________
Bool_t TArtRIPS::RecoDelta()
{
  if(!matrix) return false;

  TVectorD * fvec = (TVectorD *)forward_fpl->GetOptVector();
  TVectorD * bvec = (TVectorD *)backward_fpl->GetOptVector();

  if(!fvec || !bvec)  // if optical vector can not be taken
    return false;

  TMatrixD xvec(2,1);
  xvec(0,0) = (*bvec)(0);
  xvec(1,0) = (*bvec)(1);

  TMatrixD rvec = invert_mat2 * (xvec - (*fvec)(0) * mat1);
  angle = rvec(0,0); // change to mrad
  delta = rvec(1,0);
  // simple_delta = (*bvec)(0) / 33.; // only for fpl-5

  return true;
}

//__________________________________________________________
Int_t TArtRIPS::GetID() {
  return para->GetID();
}
//__________________________________________________________
Int_t TArtRIPS::GetForwardFpl() {
  return para->GetForwardFpl();
}
//__________________________________________________________
Int_t TArtRIPS::GetBackwardFpl() {
  return para->GetBackwardFpl();
}

//__________________________________________________________
Double_t TArtRIPS::GetBrho(){
  return para->GetBrho() * (1+delta/100.);
}

//__________________________________________________________
Double_t TArtRIPS::GetLength(){
  return backward_fpl->GetZpos() - forward_fpl->GetZpos();
}
